**Purpose**: A highly customizable homepage (or startpage / application dashboard) with Docker and service API integrations.

```yaml title="docker-compose.yml"
version: '3.8'
services:
  homepage:
    image: ghcr.io/gethomepage/homepage:latest
    container_name: homepage
    volumes:
      - /srv/containers/homepage-docker:/config
      - /srv/containers/homepage-docker/icons:/app/public/icons
    ports:
      - 80:80
      - 443:443
      - 3000:3000
    environment:
      - PUID=1000
      - PGID=1000
      - TZ=America/Denver
      - HOMEPAGE_ALLOWED_HOSTS=servers.bunny-lab.io
    dns:
      - 192.168.3.25
      - 192.168.3.26
    restart: unless-stopped
    extra_hosts:
      - "rancher.bunny-lab.io:192.168.3.21"
    networks:
        docker_network:
          ipv4_address: 192.168.5.44    

  dockerproxy:
    image: ghcr.io/tecnativa/docker-socket-proxy:latest
    container_name: dockerproxy
    environment:
      - CONTAINERS=1 # Allow access to viewing containers
      - SERVICES=1 # Allow access to viewing services (necessary when using Docker Swarm)
      - TASKS=1 # Allow access to viewing tasks (necessary when using Docker Swarm)
      - POST=0 # Disallow any POST operations (effectively read-only)
    ports:
      - 127.0.0.1:2375:2375
    volumes:
      - /var/run/docker.sock:/var/run/docker.sock:ro # Mounted as read-only
    restart: unless-stopped
    networks:
        docker_network:
          ipv4_address: 192.168.5.46   
          
networks:
  default:
    external:
      name: docker_network
  docker_network:
    external: true
```

```yaml title=".env"
Not Applicable
```
